================================
``psyclone.core.symbolic_maths``
================================

.. automodule:: psyclone.core.symbolic_maths

   .. contents::
      :local:

.. currentmodule:: psyclone.core.symbolic_maths
